# data-layer-lib

Database Layer Library

# introduction

This is a library package for handling database models.

# Getting Started

1- Clone the repository

2- To manually create a virtualenv

$ python -m venv .venv

3- To install all the dependencies

$ poetry install

4- To create a migration for the first time, execute the following command

$ alembic revision --autogenerate -m "migration name"

The same command can be used to generate a new migrations

5- Verify the alembic autogenerated db scripts

6- To apply migrations, execute the following command. This will to create/update tables in the database

$ alembic upgrade head
